@@ -12,7 +12,7 @@ from .mthreading import NewsPool
 from .utils import get_languages, get_available_languages, fulltext
 from .version import __version__
 
-__title__ = 'scraper'
+__title__ = 'stimson-web-scraper'
 __author__ = 'Lucas Ou-Yang'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2014, Lucas Ou-Yang'
