@@ -19,7 +19,7 @@ from . import urls
 from .urls import prepare_url, is_url
 from .utils import StringReplacement, StringSplitter, parse_date_str
 
-__title__ = 'scraper'
+__title__ = 'stimson-web-scraper'
 __author__ = 'Lucas Ou-Yang'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2014, Lucas Ou-Yang'
@@ -650,7 +650,6 @@ class ContentExtractor(object):
             nodes_to_check = self.nodes_to_check_soap(html)
         starting_boost = float(1.0)
         cnt = 0
-        i = 0
         parent_nodes = []
         nodes_with_text = []
 
