@@ -11,7 +11,7 @@ from urllib.parse import parse_qs, urljoin, urlparse, urlsplit, urlunsplit
 
 from tldextract import tldextract
 
-__title__ = 'scraper'
+__title__ = 'stimson-web-scraper'
 __author__ = 'Lucas Ou-Yang'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2014, Lucas Ou-Yang'
