@@ -3,12 +3,12 @@
 To change the version of entire package, just edit this one location.
 """
 
-__title__ = 'scraper'
+__title__ = 'stimson-web-scraper'
 __author__ = 'Lucas Ou-Yang'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2014, Lucas Ou-Yang'
 __maintainer__ = "The Stimson Center"
 __maintainer_email = "cooper@pobox.com"
 
-version_info = (0, 0, 53)
+version_info = (0, 0, 58)
 __version__ = ".".join(map(str, version_info))
